<?php
/**
 * A money bank which may lend points to the user
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 Ship-Simu Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class MoneyBank extends BaseBank implements Registerable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this money bank class
	 *
	 * @param	$userInstance	A class instance of a user object
	 * @return	$bankInstance	An instance of this class
	 */
	public static final function createMoneyBank (ManageableAccount $userInstance) {
		// Get a new instance
		$moneyInstance = new MoneyBank();

		// Set the user instance
		$moneyInstance->setUserInstance($userInstance);

		// Return the prepared instance
		return $moneyInstance;
	}

	/**
	 * Checks wether the bank lends more money to the current user
	 *
	 * @return	$lendsMoreMoney		Wether this bank lends more money to the user
	 */
	public function ifBankLendsMoreMoney () {
		$this->partialStub();
	}

	/**
	 * Checks wethert the current user has maximum allowed credits with this bank
	 *
	 * @return	$hasMaximumCredits	Wether the user has maximum allowed credits
	 */
	public function ifUserHasMaxCredits () {
		$this->partialStub();
	}

	/**
	 * Checks wether this money bank has opened
	 *
	 * @return	$hasOpened	Wether this money bank has opened
	 */
	public function ifMoneyBankHasOpened () {
		// Has not opened by default
		$hasOpened = false;

		// Is the money bank activated in config?
		if ($this->getConfigInstance()->getConfigEntry('moneybank_activated')) {
			// Okay, does the user ask within the opening times? To find this out we need a OpeningTimes class
			$openingInstance = ObjectFactory::createObjectByConfiguredName('moneybank_opening_class', array($this));

			// Then we simply "ask" the opening time instance if the user asks within the opening time
			$hasOpened = $openingInstance->ifWithinOpeningTimes();
		} // END - if

		// Return status
		return $hasOpened;
	}
}

// [EOF]
?>
